# InferLO

Python library for Inference, Learning and Optimization with Graphical Models.

[![PyPI version](https://badge.fury.io/py/inferlo.svg)](https://badge.fury.io/py/inferlo)
[![Documentation Status](https://readthedocs.org/projects/inferlo/badge/?version=latest)](https://inferlo.readthedocs.io/en/latest/?badge=latest)


### Installing

Library can be installed using pip: `pip install inferlo`

### Documentation

Documentation is available at https://inferlo.readthedocs.io.

### Contributing

You can contribute to the library by creating pull requests. 
Please follow these [guideleines](https://inferlo.readthedocs.io/en/latest/contributing.html).

### Authors

* Misha Chertkov
* Dmytro Fedoriaka
* Mikhail Krechetov
